@@ -1,7 +1,5 @@
 import logging
-from typing import Iterator, Optional
-
-from archinfo import RegisterOffset, TmpVar
+from collections.abc import Iterator
 
 from . import expr
 from .const import IRConst
@@ -18,13 +16,13 @@ class IRStmt(VEXObject):
     IR statements in VEX represents operations with side-effects.
     """
 
-    tag: Optional[str] = None
+    tag: str | None = None
     tag_int = 0  # set automatically at bottom of file
 
     __slots__ = []
 
     def pp(self):
-        print(self.__str__())
+        print(str(self))
 
     @property
     def child_expressions(self) -> Iterator["IRExpr"]:
@@ -51,7 +49,7 @@ class IRStmt(VEXObject):
             return None
 
         try:
-            stmt_class = enum_to_stmt_class(c_stmt.tag)._from_c(c_stmt)
+            stmt_class = enum_to_stmt_class(c_stmt.tag)
         except KeyError:
             raise PyVEXError("Unknown/unsupported IRStmtTag %s.\n" % get_enum_from_int(c_stmt.tag))
         return stmt_class._from_c(c_stmt)
@@ -86,7 +84,10 @@ class IRStmt(VEXObject):
                 if replaced:
                     setattr(self, k, tuple(_lst))
 
-    def __str__(self, reg_name=None, arch=None, tyenv=None):
+    def __str__(self):
+        return self.pp_str(None, None, None)
+
+    def pp_str(self, reg_name=None, arch=None, tyenv=None) -> str:
         raise NotImplementedError()
 
 
@@ -99,7 +100,7 @@ class NoOp(IRStmt):
 
     tag = "Ist_NoOp"
 
-    def __str__(self, reg_name=None, arch=None, tyenv=None):
+    def pp_str(self, reg_name=None, arch=None, tyenv=None):
         return "IR-NoOp"
 
     @staticmethod
@@ -123,7 +124,7 @@ class IMark(IRStmt):
         self.len = length
         self.delta = delta
 
-    def __str__(self, reg_name=None, arch=None, tyenv=None):
+    def pp_str(self, reg_name=None, arch=None, tyenv=None):
         return "------ IMark(0x%x, %d, %d) ------" % (self.addr, self.len, self.delta)
 
     @staticmethod
@@ -145,7 +146,7 @@ class AbiHint(IRStmt):
         self.len = length
         self.nia = nia
 
-    def __str__(self, reg_name=None, arch=None, tyenv=None):
+    def pp_str(self, reg_name=None, arch=None, tyenv=None):
         return "====== AbiHint(0x%s, %d, %s) ======" % (self.base, self.len, self.nia)
 
     @staticmethod
@@ -164,12 +165,12 @@ class Put(IRStmt):
 
     tag = "Ist_Put"
 
-    def __init__(self, data: "IRExpr", offset: RegisterOffset):
+    def __init__(self, data: "IRExpr", offset):
         self.data = data
         self.offset = offset
 
     ## TODO: Check if result_size and arch are available before looking of arch register name
-    def __str__(self, reg_name=None, arch=None, tyenv=None):
+    def pp_str(self, reg_name=None, arch=None, tyenv=None):
         if arch is not None and tyenv is not None:
             reg_name = arch.translate_register_name(self.offset, self.data.result_size(tyenv) // 8)
 
@@ -201,7 +202,7 @@ class PutI(IRStmt):
         self.data = data
         self.bias = bias
 
-    def __str__(self, reg_name=None, arch=None, tyenv=None):
+    def pp_str(self, reg_name=None, arch=None, tyenv=None):
         return "PutI(%s)[%s,%d] = %s" % (self.descr, self.ix, self.bias, self.data)
 
     @staticmethod
@@ -233,18 +234,18 @@ class WrTmp(IRStmt):
 
     tag = "Ist_WrTmp"
 
-    def __init__(self, tmp: TmpVar, data: "IRExpr"):
+    def __init__(self, tmp, data: "IRExpr"):
         self.tmp = tmp
         self.data = data
 
-    def __str__(self, reg_name=None, arch=None, tyenv=None):
+    def pp_str(self, reg_name=None, arch=None, tyenv=None):
         # Support for named register in string representation of expr.Get
 
         if arch is not None and tyenv is not None and isinstance(self.data, Get):
             reg_name = arch.translate_register_name(self.data.offset, self.data.result_size(tyenv) // 8)
 
         if reg_name is not None and isinstance(self.data, expr.Get):
-            return "t%d = %s" % (self.tmp, self.data.__str__(reg_name=reg_name))
+            return "t%d = %s" % (self.tmp, self.data.pp_str_with_name(reg_name))
         else:
             return "t%d = %s" % (self.tmp, self.data)
 
@@ -280,7 +281,7 @@ class Store(IRStmt):
     def endness(self):
         return self.end
 
-    def __str__(self, reg_name=None, arch=None, tyenv=None):
+    def pp_str(self, reg_name=None, arch=None, tyenv=None):
         return f"ST{self.endness[-2:].lower()}({self.addr}) = {self.data}"
 
     @staticmethod
@@ -330,7 +331,7 @@ class CAS(IRStmt):
     def endness(self):
         return self.end
 
-    def __str__(self, reg_name=None, arch=None, tyenv=None):
+    def pp_str(self, reg_name=None, arch=None, tyenv=None):
         return "t({},{}) = CAS{}({} :: ({},{})->({},{}))".format(
             self.oldLo, self.oldHi, self.end[-2:].lower(), self.addr, self.expdLo, self.expdHi, self.dataLo, self.dataHi
         )
@@ -412,7 +413,7 @@ class LLSC(IRStmt):
     def endness(self):
         return self.end
 
-    def __str__(self, reg_name=None, arch=None, tyenv=None):
+    def pp_str(self, reg_name=None, arch=None, tyenv=None):
         if self.storedata is None:
             return "t%d = LD%s-Linked(%s)" % (self.result, self.end[-2:].lower(), self.addr)
         else:
@@ -459,7 +460,7 @@ class MBE(IRStmt):
     def __init__(self, event):
         self.event = event
 
-    def __str__(self, reg_name=None, arch=None, tyenv=None):
+    def pp_str(self, reg_name=None, arch=None, tyenv=None):
         return "MBusEvent-" + self.event
 
     @staticmethod
@@ -482,7 +483,7 @@ class Dirty(IRStmt):
         self.mSize = mSize
         self.nFxState = nFxState
 
-    def __str__(self, reg_name=None, arch=None, tyenv=None):
+    def pp_str(self, reg_name=None, arch=None, tyenv=None):
         return "t{} = DIRTY {} {} ::: {}({})".format(
             self.tmp, self.guard, "TODO(effects)", self.cee, ",".join(str(a) for a in self.args)
         )
@@ -536,7 +537,7 @@ class Exit(IRStmt):
     def jumpkind(self):
         return self.jk
 
-    def __str__(self, reg_name=None, arch=None, tyenv=None):
+    def pp_str(self, reg_name=None, arch=None, tyenv=None):
         if arch is not None and tyenv is not None:
             reg_name = arch.translate_register_name(self.offsIP, arch.bits // 8)
 
@@ -599,7 +600,7 @@ class LoadG(IRStmt):
     def endness(self):
         return self.end
 
-    def __str__(self, reg_name=None, arch=None, tyenv=None):
+    def pp_str(self, reg_name=None, arch=None, tyenv=None):
         return "t%d = if (%s) %s(LD%s(%s)) else %s" % (
             self.dst,
             self.guard,
@@ -668,7 +669,7 @@ class StoreG(IRStmt):
     def endness(self):
         return self.end
 
-    def __str__(self, reg_name=None, arch=None, tyenv=None):
+    def pp_str(self, reg_name=None, arch=None, tyenv=None):
         return f"if ({self.guard}) ST{self.end[-2:].lower()}({self.addr}) = {self.data}"
 
     @staticmethod
